import { getDevOpsCore } from '@thatdevops/core/devopsCore'
import getProjectPkgs from '@thatdevops/core/pkgman/getProjectPkgs'
import Pkg from '@thatdevops/core/pkgman/Pkg'
import spawnSilently from '@thatdevops/core/utils/spawnSilently'

export async function doFindChangedPackages(): Promise<Pkg[]> {
	const { rootPath } = getDevOpsCore()
	const pkgs = await getProjectPkgs()
	const changed = []
	for (const pkg of pkgs) {
		const lastDate = pkg.json.devops?.lastPublished ?? '2020-01-01T00:00:00Z'
		const fls = await spawnSilently(
			'git',
			['log', '--name-only', '--pretty=oneline', `--since="${lastDate}"`, pkg.relativePath],
			rootPath
		)
		if (fls.length) changed.push(pkg)
	}
	return changed
}
export default doFindChangedPackages
